==> faas-0.0.24.tgz: package/ix-server/polyglot_relay.js <==
var net = require('net')
  , Base = require('../base')
  , Publisher = require('./publisher')
  , Connector = require('./connector')

var debug = Base.logger('ix-polyglot_relay')

var SOCKET_CONFIG


exports.start = function(socketDef, cb_err_data){
  socketOpts = socketDef.split(':')
  type = socketOpts.shift()
  if (type === 'unix') {
    startUnixSocket(socketOpts[0], cb_err_data)
  }
  else {
    startTcpSocket(socketOpts[0], socketOpts[1], cb_err_data)
  }
}

var startTcpSocket = function(host, port, cb_err_data){
  SOCKET_CONFIG = { allowHalfOpen: true, host: host, port: port }
  startSocket(cb_err_data)
}

var startUnixSocket = function(socketPath, cb_err_data){
  SOCKET_CONFIG = { allowHalfOpen: true, path: socketPath }
  startSocket(cb_err_data)
}

var startSocket = function(cb_err_data){
  debug('start', SOCKET_CONFIG)
  Base.env(function(){
    var exportsInfoJson = ''
    var client = net.connect(SOCKET_CONFIG, function(){
      debug('connected to relay')
      client.end(JSON.stringify({ IX_DIR: Base.env.IX_DIR }))
    })
    client.on('data', function(info){
      exportsInfoJson += info.toString()
    })
    client.on('end', function(){
      var exportsInfo = JSON.parse(exportsInfoJson)
      debug('exportsInfo', exportsInfo)
      Publisher.publishExportsAndGetProxy(exportsInfo, function(err, data){
        if (err && !cb_err_data) { throw err }
        if (err) { cb_err_data(err, data); return }

        Connector.connectRelayToProxy(data, function(err, data){
          if (err && !cb_err_data) { throw err }
          if (cb_err_data) { cb_err_data(err, data) }
        })
      })
    })
  })
}

exports.invoker = function(callData, cb_err_data){
  debug('invoker', callData)

//  cb_err_data(null, callData); return

  var errDataJson = ''
  var relay = net.connect(SOCKET_CONFIG, function(){
    relay.end(JSON.stringify(callData))
  })
  relay.on('data', function(data){
    errDataJson += data.toString()
  })
  relay.on('end', function(){
    var errData = JSON.parse(errDataJson)
    debug('errData', errData)
    cb_err_data(errData.err, errData.data)
  })
  relay.on('error', function(err){
    debug('error', err)
    cb_err_data(err)
  })
}

==> faas-0.0.32.tgz: package/ix-server/polyglot_relay.js <==
var net = require('net')
  , Base = require('../base')
  , Publisher = require('./publisher')
  , Connector = require('./connector')
  , LoggingFilter = require('./logging_filter')

var debug = Base.logger('ix-polyglot_relay')

var SOCKET_CONFIG


exports.start = function(socketDef, cb_err_data){
  LoggingFilter.load(function(){
    socketOpts = socketDef.split(':')
    type = socketOpts.shift()
    if (type === 'unix') {
      startUnixSocket(socketOpts[0], cb_err_data)
    }
    else {
      startTcpSocket(socketOpts[0], socketOpts[1], cb_err_data)
    }
  })
}

var startTcpSocket = function(host, port, cb_err_data){
  SOCKET_CONFIG = { allowHalfOpen: true, host: host, port: port }
  startSocket(cb_err_data)
}

var startUnixSocket = function(socketPath, cb_err_data){
  SOCKET_CONFIG = { allowHalfOpen: true, path: socketPath }
  startSocket(cb_err_data)
}

var startSocket = function(cb_err_data){
  debug('start', SOCKET_CONFIG)
  Base.env(function(){
    var exportsInfoJson = ''
    var client = net.connect(SOCKET_CONFIG, function(){
      debug('connected to relay')
      client.end(JSON.stringify({ IX_DIR: Base.env.IX_DIR }))
    })
    client.on('data', function(info){
      exportsInfoJson += info.toString()
    })
    client.on('end', function(){
      var exportsInfo = JSON.parse(exportsInfoJson)
      debug('exportsInfo', exportsInfo)
      Publisher.publishExportsAndGetProxy(exportsInfo, function(err, data){
        if (err && !cb_err_data) { throw err }
        if (err) { cb_err_data(err, data); return }

        Connector.connectRelayToProxy(data, function(err, data){
          if (err && !cb_err_data) { throw err }
          if (cb_err_data) { cb_err_data(err, data) }
        })
      })
    })
  })
}

exports.invoker = function(callData, cb_err_data){
  debug('invoker', callData)

//  cb_err_data(null, callData); return

  var errDataJson = ''
  var relay = net.connect(SOCKET_CONFIG, function(){
    relay.end(JSON.stringify(LoggingFilter.addFilteredData(callData)))
  })
  relay.on('data', function(data){
    errDataJson += data.toString()
  })
  relay.on('end', function(){
    var errData = JSON.parse(errDataJson)
    debug('errData', errData)
    cb_err_data(errData.err, errData.data)
  })
  relay.on('error', function(err){
    debug('error', err)
    cb_err_data(err)
  })
}
